from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TDF import *
from OCC.Core.TopTools import *
from OCC.Core.TopLoc import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *
from OCC.Core.TColStd import *
from OCC.Core.TopAbs import *

#the following typedef cannot be wrapped as is
TNaming_DataMapIteratorOfDataMapOfShapeMapOfShape = NewType('TNaming_DataMapIteratorOfDataMapOfShapeMapOfShape', Any)
#the following typedef cannot be wrapped as is
TNaming_MapIteratorOfMapOfNamedShape = NewType('TNaming_MapIteratorOfMapOfNamedShape', Any)
#the following typedef cannot be wrapped as is
TNaming_MapIteratorOfMapOfShape = NewType('TNaming_MapIteratorOfMapOfShape', Any)
#the following typedef cannot be wrapped as is
TNaming_MapOfNamedShape = NewType('TNaming_MapOfNamedShape', Any)
#the following typedef cannot be wrapped as is
TNaming_MapOfShape = NewType('TNaming_MapOfShape', Any)
#the following typedef cannot be wrapped as is
TNaming_NamedShapeHasher = NewType('TNaming_NamedShapeHasher', Any)
TNaming_PtrAttribute = NewType('TNaming_PtrAttribute', TNaming_NamedShape)
TNaming_PtrNode = NewType('TNaming_PtrNode', TNaming_Node)
TNaming_PtrRefShape = NewType('TNaming_PtrRefShape', TNaming_RefShape)

class TNaming_ListOfIndexedDataMapOfShapeListOfShape:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TopTools_IndexedDataMapOfShapeListOfShape: ...
    def Last(self) -> TopTools_IndexedDataMapOfShapeListOfShape: ...
    def Append(self, theItem: TopTools_IndexedDataMapOfShapeListOfShape) -> TopTools_IndexedDataMapOfShapeListOfShape: ...
    def Prepend(self, theItem: TopTools_IndexedDataMapOfShapeListOfShape) -> TopTools_IndexedDataMapOfShapeListOfShape: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TopTools_IndexedDataMapOfShapeListOfShape: ...
    def SetValue(self, theIndex: int, theValue: TopTools_IndexedDataMapOfShapeListOfShape) -> None: ...

class TNaming_ListOfMapOfShape:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TopTools_MapOfShape: ...
    def Last(self) -> TopTools_MapOfShape: ...
    def Append(self, theItem: TopTools_MapOfShape) -> TopTools_MapOfShape: ...
    def Prepend(self, theItem: TopTools_MapOfShape) -> TopTools_MapOfShape: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TopTools_MapOfShape: ...
    def SetValue(self, theIndex: int, theValue: TopTools_MapOfShape) -> None: ...

class TNaming_ListOfNamedShape:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class TNaming_Evolution(IntEnum):
	TNaming_PRIMITIVE: int = ...
	TNaming_GENERATED: int = ...
	TNaming_MODIFY: int = ...
	TNaming_DELETE: int = ...
	TNaming_REPLACE: int = ...
	TNaming_SELECTED: int = ...
TNaming_PRIMITIVE = TNaming_Evolution.TNaming_PRIMITIVE
TNaming_GENERATED = TNaming_Evolution.TNaming_GENERATED
TNaming_MODIFY = TNaming_Evolution.TNaming_MODIFY
TNaming_DELETE = TNaming_Evolution.TNaming_DELETE
TNaming_REPLACE = TNaming_Evolution.TNaming_REPLACE
TNaming_SELECTED = TNaming_Evolution.TNaming_SELECTED

class TNaming_NameType(IntEnum):
	TNaming_UNKNOWN: int = ...
	TNaming_IDENTITY: int = ...
	TNaming_MODIFUNTIL: int = ...
	TNaming_GENERATION: int = ...
	TNaming_INTERSECTION: int = ...
	TNaming_UNION: int = ...
	TNaming_SUBSTRACTION: int = ...
	TNaming_CONSTSHAPE: int = ...
	TNaming_FILTERBYNEIGHBOURGS: int = ...
	TNaming_ORIENTATION: int = ...
	TNaming_WIREIN: int = ...
	TNaming_SHELLIN: int = ...
TNaming_UNKNOWN = TNaming_NameType.TNaming_UNKNOWN
TNaming_IDENTITY = TNaming_NameType.TNaming_IDENTITY
TNaming_MODIFUNTIL = TNaming_NameType.TNaming_MODIFUNTIL
TNaming_GENERATION = TNaming_NameType.TNaming_GENERATION
TNaming_INTERSECTION = TNaming_NameType.TNaming_INTERSECTION
TNaming_UNION = TNaming_NameType.TNaming_UNION
TNaming_SUBSTRACTION = TNaming_NameType.TNaming_SUBSTRACTION
TNaming_CONSTSHAPE = TNaming_NameType.TNaming_CONSTSHAPE
TNaming_FILTERBYNEIGHBOURGS = TNaming_NameType.TNaming_FILTERBYNEIGHBOURGS
TNaming_ORIENTATION = TNaming_NameType.TNaming_ORIENTATION
TNaming_WIREIN = TNaming_NameType.TNaming_WIREIN
TNaming_SHELLIN = TNaming_NameType.TNaming_SHELLIN

class tnaming:
	@staticmethod
	def ChangeShapes(label: TDF_Label, M: TopTools_DataMapOfShapeShape) -> None: ...
	@staticmethod
	def Displace(label: TDF_Label, aLocation: TopLoc_Location, WithOld: Optional[bool] = True) -> None: ...
	@staticmethod
	def FindUniqueContext(S: TopoDS_Shape, Context: TopoDS_Shape) -> TopoDS_Shape: ...
	@staticmethod
	def FindUniqueContextSet(S: TopoDS_Shape, Context: TopoDS_Shape, Arr: TopTools_HArray1OfShape) -> TopoDS_Shape: ...
	@staticmethod
	def IDList(anIDList: TDF_IDList) -> None: ...
	@staticmethod
	def MakeShape(MS: TopTools_MapOfShape) -> TopoDS_Shape: ...
	@staticmethod
	def OuterShell(theSolid: TopoDS_Solid, theShell: TopoDS_Shell) -> bool: ...
	@staticmethod
	def OuterWire(theFace: TopoDS_Face, theWire: TopoDS_Wire) -> bool: ...
	@overload
	@staticmethod
	def Replicate(NS: TNaming_NamedShape, T: gp_Trsf, L: TDF_Label) -> None: ...
	@overload
	@staticmethod
	def Replicate(SH: TopoDS_Shape, T: gp_Trsf, L: TDF_Label) -> None: ...
	@staticmethod
	def Substitute(labelsource: TDF_Label, labelcible: TDF_Label, mapOldNew: TopTools_DataMapOfShapeShape) -> None: ...
	@staticmethod
	def SubstituteSShape(accesslabel: TDF_Label, From: TopoDS_Shape, To: TopoDS_Shape) -> bool: ...
	@staticmethod
	def Transform(label: TDF_Label, aTransformation: gp_Trsf) -> None: ...
	@staticmethod
	def Update(label: TDF_Label, mapOldNew: TopTools_DataMapOfShapeShape) -> None: ...

class TNaming_Builder:
	def __init__(self, aLabel: TDF_Label) -> None: ...
	def Delete(self, oldShape: TopoDS_Shape) -> None: ...
	@overload
	def Generated(self, newShape: TopoDS_Shape) -> None: ...
	@overload
	def Generated(self, oldShape: TopoDS_Shape, newShape: TopoDS_Shape) -> None: ...
	def Modify(self, oldShape: TopoDS_Shape, newShape: TopoDS_Shape) -> None: ...
	def NamedShape(self) -> TNaming_NamedShape: ...
	def Select(self, aShape: TopoDS_Shape, inShape: TopoDS_Shape) -> None: ...

class TNaming_CopyShape:
	@staticmethod
	def CopyTool(aShape: TopoDS_Shape, aMap: TColStd_IndexedDataMapOfTransientTransient, aResult: TopoDS_Shape) -> None: ...
	@overload
	@staticmethod
	def Translate(aShape: TopoDS_Shape, aMap: TColStd_IndexedDataMapOfTransientTransient, aResult: TopoDS_Shape, TrTool: TNaming_TranslateTool) -> None: ...
	@overload
	@staticmethod
	def Translate(L: TopLoc_Location, aMap: TColStd_IndexedDataMapOfTransientTransient) -> TopLoc_Location: ...

class TNaming_DeltaOnModification(TDF_DeltaOnModification):
	def __init__(self, NS: TNaming_NamedShape) -> None: ...
	def Apply(self) -> None: ...

class TNaming_DeltaOnRemoval(TDF_DeltaOnRemoval):
	def __init__(self, NS: TNaming_NamedShape) -> None: ...
	def Apply(self) -> None: ...

class TNaming_Identifier:
	@overload
	def __init__(self, Lab: TDF_Label, S: TopoDS_Shape, Context: TopoDS_Shape, Geom: bool) -> None: ...
	@overload
	def __init__(self, Lab: TDF_Label, S: TopoDS_Shape, ContextNS: TNaming_NamedShape, Geom: bool) -> None: ...
	def AncestorIdentification(self, Localizer: TNaming_Localizer, Context: TopoDS_Shape) -> None: ...
	def ArgIsFeature(self) -> bool: ...
	def Feature(self) -> TNaming_NamedShape: ...
	def FeatureArg(self) -> TNaming_NamedShape: ...
	def GeneratedIdentification(self, Localizer: TNaming_Localizer, NS: TNaming_NamedShape) -> None: ...
	def Identification(self, Localizer: TNaming_Localizer, NS: TNaming_NamedShape) -> None: ...
	def InitArgs(self) -> None: ...
	def IsDone(self) -> bool: ...
	def IsFeature(self) -> bool: ...
	def MoreArgs(self) -> bool: ...
	def NamedShapeOfGeneration(self) -> TNaming_NamedShape: ...
	def NextArg(self) -> None: ...
	def PrimitiveIdentification(self, Localizer: TNaming_Localizer, NS: TNaming_NamedShape) -> None: ...
	def ShapeArg(self) -> TopoDS_Shape: ...
	def ShapeContext(self) -> TopoDS_Shape: ...
	def Type(self) -> TNaming_NameType: ...

class TNaming_Iterator:
	@overload
	def __init__(self, anAtt: TNaming_NamedShape) -> None: ...
	@overload
	def __init__(self, aLabel: TDF_Label) -> None: ...
	@overload
	def __init__(self, aLabel: TDF_Label, aTrans: int) -> None: ...
	def Evolution(self) -> TNaming_Evolution: ...
	def IsModification(self) -> bool: ...
	def More(self) -> bool: ...
	def NewShape(self) -> TopoDS_Shape: ...
	def Next(self) -> None: ...
	def OldShape(self) -> TopoDS_Shape: ...

class TNaming_IteratorOnShapesSet:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TNaming_ShapesSet) -> None: ...
	def Init(self, S: TNaming_ShapesSet) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Value(self) -> TopoDS_Shape: ...

class TNaming_Localizer:
	def __init__(self) -> None: ...
	def Ancestors(self, S: TopoDS_Shape, Type: TopAbs_ShapeEnum) -> TopTools_IndexedDataMapOfShapeListOfShape: ...
	def Backward(self, NS: TNaming_NamedShape, S: TopoDS_Shape, Primitives: TNaming_MapOfNamedShape, ValidShapes: TopTools_MapOfShape) -> None: ...
	def FindFeaturesInAncestors(self, S: TopoDS_Shape, In: TopoDS_Shape, AncInFeatures: TopTools_MapOfShape) -> None: ...
	@staticmethod
	def FindGenerator(NS: TNaming_NamedShape, S: TopoDS_Shape, theListOfGenerators: TopTools_ListOfShape) -> None: ...
	def FindNeighbourg(self, Cont: TopoDS_Shape, S: TopoDS_Shape, Neighbourg: TopTools_MapOfShape) -> None: ...
	@staticmethod
	def FindShapeContext(NS: TNaming_NamedShape, theS: TopoDS_Shape, theSC: TopoDS_Shape) -> None: ...
	def GoBack(self, S: TopoDS_Shape, Lab: TDF_Label, Evol: TNaming_Evolution, OldS: TopTools_ListOfShape, OldLab: TNaming_ListOfNamedShape) -> None: ...
	def Init(self, US: TNaming_UsedShapes, CurTrans: int) -> None: ...
	@staticmethod
	def IsNew(S: TopoDS_Shape, NS: TNaming_NamedShape) -> bool: ...
	def SubShapes(self, S: TopoDS_Shape, Type: TopAbs_ShapeEnum) -> TopTools_MapOfShape: ...

class TNaming_Name:
	def __init__(self) -> None: ...
	def Append(self, arg: TNaming_NamedShape) -> None: ...
	def Arguments(self) -> TNaming_ListOfNamedShape: ...
	@overload
	def ContextLabel(self, theLab: TDF_Label) -> None: ...
	@overload
	def ContextLabel(self) -> TDF_Label: ...
	@overload
	def Index(self, I: int) -> None: ...
	@overload
	def Index(self) -> int: ...
	@overload
	def Orientation(self, theOrientation: TopAbs_Orientation) -> None: ...
	@overload
	def Orientation(self) -> TopAbs_Orientation: ...
	def Paste(self, into: TNaming_Name, RT: TDF_RelocationTable) -> None: ...
	@overload
	def Shape(self, theShape: TopoDS_Shape) -> None: ...
	@overload
	def Shape(self) -> TopoDS_Shape: ...
	@overload
	def ShapeType(self, aType: TopAbs_ShapeEnum) -> None: ...
	@overload
	def ShapeType(self) -> TopAbs_ShapeEnum: ...
	def Solve(self, aLab: TDF_Label, Valid: TDF_LabelMap) -> bool: ...
	@overload
	def StopNamedShape(self, arg: TNaming_NamedShape) -> None: ...
	@overload
	def StopNamedShape(self) -> TNaming_NamedShape: ...
	@overload
	def Type(self, aType: TNaming_NameType) -> None: ...
	@overload
	def Type(self) -> TNaming_NameType: ...

class TNaming_NamedShape(TDF_Attribute):
	def __init__(self) -> None: ...
	def AfterUndo(self, anAttDelta: TDF_AttributeDelta, forceIt: Optional[bool] = False) -> bool: ...
	def BackupCopy(self) -> TDF_Attribute: ...
	def BeforeRemoval(self) -> None: ...
	def BeforeUndo(self, anAttDelta: TDF_AttributeDelta, forceIt: Optional[bool] = False) -> bool: ...
	def Clear(self) -> None: ...
	@overload
	def DeltaOnModification(self, anOldAttribute: TDF_Attribute) -> TDF_DeltaOnModification: ...
	@overload
	def DeltaOnModification(self, aDelta: TDF_DeltaOnModification) -> None: ...
	def DeltaOnRemoval(self) -> TDF_DeltaOnRemoval: ...
	def Evolution(self) -> TNaming_Evolution: ...
	def Get(self) -> TopoDS_Shape: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def IsEmpty(self) -> bool: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, intoAttribute: TDF_Attribute, aRelocTationable: TDF_RelocationTable) -> None: ...
	def References(self, aDataSet: TDF_DataSet) -> None: ...
	def Restore(self, anAttribute: TDF_Attribute) -> None: ...
	def SetVersion(self, version: int) -> None: ...
	def Version(self) -> int: ...

class TNaming_Naming(TDF_Attribute):
	def __init__(self) -> None: ...
	def ChangeName(self) -> TNaming_Name: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def GetName(self) -> TNaming_Name: ...
	def ID(self) -> Standard_GUID: ...
	@staticmethod
	def Insert(under: TDF_Label) -> TNaming_Naming: ...
	def IsDefined(self) -> bool: ...
	@staticmethod
	def Name(where: TDF_Label, Selection: TopoDS_Shape, Context: TopoDS_Shape, Geometry: Optional[bool] = False, KeepOrientation: Optional[bool] = False, BNproblem: Optional[bool] = False) -> TNaming_NamedShape: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, Into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def References(self, aDataSet: TDF_DataSet) -> None: ...
	def Regenerate(self, scope: TDF_LabelMap) -> bool: ...
	def Restore(self, With: TDF_Attribute) -> None: ...
	def Solve(self, scope: TDF_LabelMap) -> bool: ...

class TNaming_NamingTool:
	@staticmethod
	def BuildDescendants(NS: TNaming_NamedShape, Labels: TDF_LabelMap) -> None: ...
	@staticmethod
	def CurrentShape(Valid: TDF_LabelMap, Forbiden: TDF_LabelMap, NS: TNaming_NamedShape, MS: TopTools_IndexedMapOfShape) -> None: ...
	@staticmethod
	def CurrentShapeFromShape(Valid: TDF_LabelMap, Forbiden: TDF_LabelMap, Acces: TDF_Label, S: TopoDS_Shape, MS: TopTools_IndexedMapOfShape) -> None: ...

class TNaming_NewShapeIterator:
	@overload
	def __init__(self, aShape: TopoDS_Shape, Transaction: int, access: TDF_Label) -> None: ...
	@overload
	def __init__(self, aShape: TopoDS_Shape, access: TDF_Label) -> None: ...
	@overload
	def __init__(self, anIterator: TNaming_NewShapeIterator) -> None: ...
	@overload
	def __init__(self, anIterator: TNaming_Iterator) -> None: ...
	def IsModification(self) -> bool: ...
	def Label(self) -> TDF_Label: ...
	def More(self) -> bool: ...
	def NamedShape(self) -> TNaming_NamedShape: ...
	def Next(self) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...

class TNaming_OldShapeIterator:
	@overload
	def __init__(self, aShape: TopoDS_Shape, Transaction: int, access: TDF_Label) -> None: ...
	@overload
	def __init__(self, aShape: TopoDS_Shape, access: TDF_Label) -> None: ...
	@overload
	def __init__(self, anIterator: TNaming_OldShapeIterator) -> None: ...
	@overload
	def __init__(self, anIterator: TNaming_Iterator) -> None: ...
	def IsModification(self) -> bool: ...
	def Label(self) -> TDF_Label: ...
	def More(self) -> bool: ...
	def NamedShape(self) -> TNaming_NamedShape: ...
	def Next(self) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...

class TNaming_RefShape:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape) -> None: ...
	@overload
	def FirstUse(self, aPtr: TNaming_PtrNode) -> None: ...
	@overload
	def FirstUse(self) -> TNaming_PtrNode: ...
	def Label(self) -> TDF_Label: ...
	def NamedShape(self) -> TNaming_NamedShape: ...
	@overload
	def Shape(self, S: TopoDS_Shape) -> None: ...
	@overload
	def Shape(self) -> TopoDS_Shape: ...

class TNaming_SameShapeIterator:
	def __init__(self, aShape: TopoDS_Shape, access: TDF_Label) -> None: ...
	def Label(self) -> TDF_Label: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...

class TNaming_Scope:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, WithValid: bool) -> None: ...
	@overload
	def __init__(self, valid: TDF_LabelMap) -> None: ...
	def ChangeValid(self) -> TDF_LabelMap: ...
	def ClearValid(self) -> None: ...
	def CurrentShape(self, NS: TNaming_NamedShape) -> TopoDS_Shape: ...
	def GetValid(self) -> TDF_LabelMap: ...
	def IsValid(self, L: TDF_Label) -> bool: ...
	def Unvalid(self, L: TDF_Label) -> None: ...
	def UnvalidChildren(self, L: TDF_Label, withroot: Optional[bool] = True) -> None: ...
	def Valid(self, L: TDF_Label) -> None: ...
	def ValidChildren(self, L: TDF_Label, withroot: Optional[bool] = True) -> None: ...
	@overload
	def WithValid(self) -> bool: ...
	@overload
	def WithValid(self, mode: bool) -> None: ...

class TNaming_Selector:
	def __init__(self, aLabel: TDF_Label) -> None: ...
	def Arguments(self, args: TDF_AttributeMap) -> None: ...
	@staticmethod
	def IsIdentified(access: TDF_Label, selection: TopoDS_Shape, NS: TNaming_NamedShape, Geometry: Optional[bool] = False) -> bool: ...
	def NamedShape(self) -> TNaming_NamedShape: ...
	@overload
	def Select(self, Selection: TopoDS_Shape, Context: TopoDS_Shape, Geometry: Optional[bool] = False, KeepOrientatation: Optional[bool] = False) -> bool: ...
	@overload
	def Select(self, Selection: TopoDS_Shape, Geometry: Optional[bool] = False, KeepOrientatation: Optional[bool] = False) -> bool: ...
	def Solve(self, Valid: TDF_LabelMap) -> bool: ...

class TNaming_ShapesSet:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, Type: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> None: ...
	@overload
	def Add(self, S: TopoDS_Shape) -> bool: ...
	@overload
	def Add(self, Shapes: TNaming_ShapesSet) -> None: ...
	def ChangeMap(self) -> TopTools_MapOfShape: ...
	def Clear(self) -> None: ...
	def Contains(self, S: TopoDS_Shape) -> bool: ...
	def Filter(self, Shapes: TNaming_ShapesSet) -> None: ...
	def IsEmpty(self) -> bool: ...
	def Map(self) -> TopTools_MapOfShape: ...
	def NbShapes(self) -> int: ...
	@overload
	def Remove(self, S: TopoDS_Shape) -> bool: ...
	@overload
	def Remove(self, Shapes: TNaming_ShapesSet) -> None: ...

class TNaming_Tool:
	@staticmethod
	def Collect(NS: TNaming_NamedShape, Labels: TNaming_MapOfNamedShape, OnlyModif: Optional[bool] = True) -> None: ...
	@overload
	@staticmethod
	def CurrentNamedShape(NS: TNaming_NamedShape, Updated: TDF_LabelMap) -> TNaming_NamedShape: ...
	@overload
	@staticmethod
	def CurrentNamedShape(NS: TNaming_NamedShape) -> TNaming_NamedShape: ...
	@overload
	@staticmethod
	def CurrentShape(NS: TNaming_NamedShape) -> TopoDS_Shape: ...
	@overload
	@staticmethod
	def CurrentShape(NS: TNaming_NamedShape, Updated: TDF_LabelMap) -> TopoDS_Shape: ...
	@staticmethod
	def FindShape(Valid: TDF_LabelMap, Forbiden: TDF_LabelMap, Arg: TNaming_NamedShape, S: TopoDS_Shape) -> None: ...
	@staticmethod
	def GeneratedShape(S: TopoDS_Shape, Generation: TNaming_NamedShape) -> TopoDS_Shape: ...
	@staticmethod
	def GetShape(NS: TNaming_NamedShape) -> TopoDS_Shape: ...
	@staticmethod
	def HasLabel(access: TDF_Label, aShape: TopoDS_Shape) -> bool: ...
	@staticmethod
	def InitialShape(aShape: TopoDS_Shape, anAcces: TDF_Label, Labels: TDF_LabelList) -> TopoDS_Shape: ...
	@staticmethod
	def Label(access: TDF_Label, aShape: TopoDS_Shape) -> Tuple[TDF_Label, int]: ...
	@staticmethod
	def NamedShape(aShape: TopoDS_Shape, anAcces: TDF_Label) -> TNaming_NamedShape: ...
	@staticmethod
	def OriginalShape(NS: TNaming_NamedShape) -> TopoDS_Shape: ...
	@staticmethod
	def ValidUntil(access: TDF_Label, S: TopoDS_Shape) -> int: ...

class TNaming_TranslateTool(Standard_Transient):
	def Add(self, S1: TopoDS_Shape, S2: TopoDS_Shape) -> None: ...
	def MakeCompSolid(self, S: TopoDS_Shape) -> None: ...
	def MakeCompound(self, S: TopoDS_Shape) -> None: ...
	def MakeEdge(self, S: TopoDS_Shape) -> None: ...
	def MakeFace(self, S: TopoDS_Shape) -> None: ...
	def MakeShell(self, S: TopoDS_Shape) -> None: ...
	def MakeSolid(self, S: TopoDS_Shape) -> None: ...
	def MakeVertex(self, S: TopoDS_Shape) -> None: ...
	def MakeWire(self, S: TopoDS_Shape) -> None: ...
	def UpdateEdge(self, S1: TopoDS_Shape, S2: TopoDS_Shape, M: TColStd_IndexedDataMapOfTransientTransient) -> None: ...
	def UpdateFace(self, S1: TopoDS_Shape, S2: TopoDS_Shape, M: TColStd_IndexedDataMapOfTransientTransient) -> None: ...
	def UpdateShape(self, S1: TopoDS_Shape, S2: TopoDS_Shape) -> None: ...
	def UpdateVertex(self, S1: TopoDS_Shape, S2: TopoDS_Shape, M: TColStd_IndexedDataMapOfTransientTransient) -> None: ...

class TNaming_Translator:
	def __init__(self) -> None: ...
	def Add(self, aShape: TopoDS_Shape) -> None: ...
	@overload
	def Copied(self, aShape: TopoDS_Shape) -> TopoDS_Shape: ...
	@overload
	def Copied(self) -> TopTools_DataMapOfShapeShape: ...
	def DumpMap(self, isWrite: Optional[bool] = False) -> None: ...
	def IsDone(self) -> bool: ...
	def Perform(self) -> None: ...

class TNaming_UsedShapes(TDF_Attribute):
	def AfterUndo(self, anAttDelta: TDF_AttributeDelta, forceIt: Optional[bool] = False) -> bool: ...
	def BackupCopy(self) -> TDF_Attribute: ...
	def BeforeRemoval(self) -> None: ...
	def DeltaOnAddition(self) -> TDF_DeltaOnAddition: ...
	def DeltaOnRemoval(self) -> TDF_DeltaOnRemoval: ...
	def Destroy(self) -> None: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def ID(self) -> Standard_GUID: ...
	def Map(self) -> TNaming_DataMapOfShapePtrRefShape: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, intoAttribute: TDF_Attribute, aRelocTationable: TDF_RelocationTable) -> None: ...
	def References(self, aDataSet: TDF_DataSet) -> None: ...
	def Restore(self, anAttribute: TDF_Attribute) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

tnaming_ChangeShapes = tnaming.ChangeShapes
tnaming_Displace = tnaming.Displace
tnaming_FindUniqueContext = tnaming.FindUniqueContext
tnaming_FindUniqueContextSet = tnaming.FindUniqueContextSet
tnaming_IDList = tnaming.IDList
tnaming_MakeShape = tnaming.MakeShape
tnaming_OuterShell = tnaming.OuterShell
tnaming_OuterWire = tnaming.OuterWire
tnaming_Print = tnaming.Print
tnaming_Print = tnaming.Print
tnaming_Print = tnaming.Print
tnaming_Replicate = tnaming.Replicate
tnaming_Replicate = tnaming.Replicate
tnaming_Substitute = tnaming.Substitute
tnaming_SubstituteSShape = tnaming.SubstituteSShape
tnaming_Transform = tnaming.Transform
tnaming_Update = tnaming.Update
TNaming_CopyShape_CopyTool = TNaming_CopyShape.CopyTool
TNaming_CopyShape_Translate = TNaming_CopyShape.Translate
TNaming_CopyShape_Translate = TNaming_CopyShape.Translate
TNaming_Localizer_FindGenerator = TNaming_Localizer.FindGenerator
TNaming_Localizer_FindShapeContext = TNaming_Localizer.FindShapeContext
TNaming_Localizer_IsNew = TNaming_Localizer.IsNew
TNaming_NamedShape_GetID = TNaming_NamedShape.GetID
TNaming_Naming_GetID = TNaming_Naming.GetID
TNaming_Naming_Insert = TNaming_Naming.Insert
TNaming_Naming_Name = TNaming_Naming.Name
TNaming_NamingTool_BuildDescendants = TNaming_NamingTool.BuildDescendants
TNaming_NamingTool_CurrentShape = TNaming_NamingTool.CurrentShape
TNaming_NamingTool_CurrentShapeFromShape = TNaming_NamingTool.CurrentShapeFromShape
TNaming_Selector_IsIdentified = TNaming_Selector.IsIdentified
TNaming_Tool_Collect = TNaming_Tool.Collect
TNaming_Tool_CurrentNamedShape = TNaming_Tool.CurrentNamedShape
TNaming_Tool_CurrentNamedShape = TNaming_Tool.CurrentNamedShape
TNaming_Tool_CurrentShape = TNaming_Tool.CurrentShape
TNaming_Tool_CurrentShape = TNaming_Tool.CurrentShape
TNaming_Tool_FindShape = TNaming_Tool.FindShape
TNaming_Tool_GeneratedShape = TNaming_Tool.GeneratedShape
TNaming_Tool_GetShape = TNaming_Tool.GetShape
TNaming_Tool_HasLabel = TNaming_Tool.HasLabel
TNaming_Tool_InitialShape = TNaming_Tool.InitialShape
TNaming_Tool_Label = TNaming_Tool.Label
TNaming_Tool_NamedShape = TNaming_Tool.NamedShape
TNaming_Tool_OriginalShape = TNaming_Tool.OriginalShape
TNaming_Tool_ValidUntil = TNaming_Tool.ValidUntil
TNaming_UsedShapes_GetID = TNaming_UsedShapes.GetID



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.ShapeExtend import *
from OCC.Core.TopTools import *
from OCC.Core.gp import *
from OCC.Core.Geom2d import *
from OCC.Core.Bnd import *
from OCC.Core.TColgp import *
from OCC.Core.Geom import *
from OCC.Core.Adaptor3d import *
from OCC.Core.TopLoc import *
from OCC.Core.TColStd import *
from OCC.Core.TopAbs import *
from OCC.Core.GeomAdaptor import *
from OCC.Core.IntRes2d import *

#the following typedef cannot be wrapped as is
ShapeAnalysis_BoxBndTree = NewType('ShapeAnalysis_BoxBndTree', Any)

class ShapeAnalysis_SequenceOfFreeBounds:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class shapeanalysis:
	@staticmethod
	def AdjustByPeriod(Val: float, ToVal: float, Period: float) -> float: ...
	@staticmethod
	def AdjustToPeriod(Val: float, ValMin: float, ValMax: float) -> float: ...
	@staticmethod
	def ContourArea(theWire: TopoDS_Wire) -> float: ...
	@staticmethod
	def FindBounds(shape: TopoDS_Shape, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@staticmethod
	def GetFaceUVBounds(F: TopoDS_Face) -> Tuple[float, float, float, float]: ...
	@staticmethod
	def IsOuterBound(face: TopoDS_Face) -> bool: ...
	@staticmethod
	def OuterWire(face: TopoDS_Face) -> TopoDS_Wire: ...
	@staticmethod
	def TotCross2D(sewd: ShapeExtend_WireData, aFace: TopoDS_Face) -> float: ...

class ShapeAnalysis_CheckSmallFace:
	def __init__(self) -> None: ...
	def CheckPin(self, F: TopoDS_Face) -> Tuple[bool, int, int]: ...
	def CheckPinEdges(self, theFirstEdge: TopoDS_Edge, theSecondEdge: TopoDS_Edge, coef1: float, coef2: float, toler: float) -> bool: ...
	def CheckPinFace(self, F: TopoDS_Face, mapEdges: TopTools_DataMapOfShapeShape, toler: Optional[float] = -1.0) -> bool: ...
	def CheckSingleStrip(self, F: TopoDS_Face, E1: TopoDS_Edge, E2: TopoDS_Edge, tol: Optional[float] = -1.0) -> bool: ...
	def CheckSplittingVertices(self, F: TopoDS_Face, MapEdges: TopTools_DataMapOfShapeListOfShape, MapParam: ShapeAnalysis_DataMapOfShapeListOfReal, theAllVert: TopoDS_Compound) -> int: ...
	def CheckSpotFace(self, F: TopoDS_Face, tol: Optional[float] = -1.0) -> bool: ...
	def CheckStripEdges(self, E1: TopoDS_Edge, E2: TopoDS_Edge, tol: float) -> Tuple[bool, float]: ...
	def CheckStripFace(self, F: TopoDS_Face, E1: TopoDS_Edge, E2: TopoDS_Edge, tol: Optional[float] = -1.0) -> bool: ...
	def CheckTwisted(self, F: TopoDS_Face) -> Tuple[bool, float, float]: ...
	def FindStripEdges(self, F: TopoDS_Face, E1: TopoDS_Edge, E2: TopoDS_Edge, tol: float) -> Tuple[bool, float]: ...
	def IsSpotFace(self, F: TopoDS_Face, spot: gp_Pnt, tol: Optional[float] = -1.0) -> Tuple[int, float]: ...
	def IsStripSupport(self, F: TopoDS_Face, tol: Optional[float] = -1.0) -> bool: ...
	def SetTolerance(self, tol: float) -> None: ...
	def Status(self, status: ShapeExtend_Status) -> bool: ...
	def StatusPin(self, status: ShapeExtend_Status) -> bool: ...
	def StatusPinEdges(self, status: ShapeExtend_Status) -> bool: ...
	def StatusPinFace(self, status: ShapeExtend_Status) -> bool: ...
	def StatusSplitVert(self, status: ShapeExtend_Status) -> bool: ...
	def StatusSpot(self, status: ShapeExtend_Status) -> bool: ...
	def StatusStrip(self, status: ShapeExtend_Status) -> bool: ...
	def StatusTwisted(self, status: ShapeExtend_Status) -> bool: ...
	def Tolerance(self) -> float: ...

class ShapeAnalysis_Curve:
	def FillBndBox(self, C2d: Geom2d_Curve, First: float, Last: float, NPoints: int, Exact: bool, Box: Bnd_Box2d) -> None: ...
	@overload
	@staticmethod
	def GetSamplePoints(curve: Geom2d_Curve, first: float, last: float, seq: TColgp_SequenceOfPnt2d) -> bool: ...
	@overload
	@staticmethod
	def GetSamplePoints(curve: Geom_Curve, first: float, last: float, seq: TColgp_SequenceOfPnt) -> bool: ...
	@staticmethod
	def IsClosed(curve: Geom_Curve, preci: Optional[float] = -1) -> bool: ...
	@overload
	@staticmethod
	def IsPeriodic(curve: Geom_Curve) -> bool: ...
	@overload
	@staticmethod
	def IsPeriodic(curve: Geom2d_Curve) -> bool: ...
	@overload
	@staticmethod
	def IsPlanar(pnts: TColgp_Array1OfPnt, Normal: gp_XYZ, preci: Optional[float] = 0) -> bool: ...
	@overload
	@staticmethod
	def IsPlanar(curve: Geom_Curve, Normal: gp_XYZ, preci: Optional[float] = 0) -> bool: ...
	@overload
	def NextProject(self, paramPrev: float, C3D: Geom_Curve, P3D: gp_Pnt, preci: float, proj: gp_Pnt, cf: float, cl: float, AdjustToEnds: Optional[bool] = True) -> Tuple[float, float]: ...
	@overload
	def NextProject(self, paramPrev: float, C3D: Adaptor3d_Curve, P3D: gp_Pnt, preci: float, proj: gp_Pnt) -> Tuple[float, float]: ...
	@overload
	def Project(self, C3D: Geom_Curve, P3D: gp_Pnt, preci: float, proj: gp_Pnt, AdjustToEnds: Optional[bool] = True) -> Tuple[float, float]: ...
	@overload
	def Project(self, C3D: Adaptor3d_Curve, P3D: gp_Pnt, preci: float, proj: gp_Pnt, AdjustToEnds: Optional[bool] = True) -> Tuple[float, float]: ...
	@overload
	def Project(self, C3D: Geom_Curve, P3D: gp_Pnt, preci: float, proj: gp_Pnt, cf: float, cl: float, AdjustToEnds: Optional[bool] = True) -> Tuple[float, float]: ...
	def ProjectAct(self, C3D: Adaptor3d_Curve, P3D: gp_Pnt, preci: float, proj: gp_Pnt) -> Tuple[float, float]: ...
	def SelectForwardSeam(self, C1: Geom2d_Curve, C2: Geom2d_Curve) -> int: ...
	def ValidateRange(self, Crv: Geom_Curve, prec: float) -> Tuple[bool, float, float]: ...

class ShapeAnalysis_Edge:
	def __init__(self) -> None: ...
	@overload
	def BoundUV(self, edge: TopoDS_Edge, face: TopoDS_Face, first: gp_Pnt2d, last: gp_Pnt2d) -> bool: ...
	@overload
	def BoundUV(self, edge: TopoDS_Edge, surface: Geom_Surface, location: TopLoc_Location, first: gp_Pnt2d, last: gp_Pnt2d) -> bool: ...
	@overload
	def CheckCurve3dWithPCurve(self, edge: TopoDS_Edge, face: TopoDS_Face) -> bool: ...
	@overload
	def CheckCurve3dWithPCurve(self, edge: TopoDS_Edge, surface: Geom_Surface, location: TopLoc_Location) -> bool: ...
	def CheckOverlapping(self, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge, theDomainDist: Optional[float] = 0.0) -> Tuple[bool, float]: ...
	def CheckPCurveRange(self, theFirst: float, theLast: float, thePC: Geom2d_Curve) -> bool: ...
	@overload
	def CheckSameParameter(self, edge: TopoDS_Edge, NbControl: Optional[int] = 23) -> Tuple[bool, float]: ...
	@overload
	def CheckSameParameter(self, theEdge: TopoDS_Edge, theFace: TopoDS_Face, theNbControl: Optional[int] = 23) -> Tuple[bool, float]: ...
	@overload
	def CheckVertexTolerance(self, edge: TopoDS_Edge, face: TopoDS_Face) -> Tuple[bool, float, float]: ...
	@overload
	def CheckVertexTolerance(self, edge: TopoDS_Edge) -> Tuple[bool, float, float]: ...
	def CheckVerticesWithCurve3d(self, edge: TopoDS_Edge, preci: Optional[float] = -1, vtx: Optional[int] = 0) -> bool: ...
	@overload
	def CheckVerticesWithPCurve(self, edge: TopoDS_Edge, face: TopoDS_Face, preci: Optional[float] = -1, vtx: Optional[int] = 0) -> bool: ...
	@overload
	def CheckVerticesWithPCurve(self, edge: TopoDS_Edge, surface: Geom_Surface, location: TopLoc_Location, preci: Optional[float] = -1, vtx: Optional[int] = 0) -> bool: ...
	@staticmethod
	def ComputeDeviation(CRef: Adaptor3d_Curve, Other: Adaptor3d_Curve, SameParameter: bool, NCONTROL: int) -> Tuple[bool, float]: ...
	def Curve3d(self, edge: TopoDS_Edge, C3d: Geom_Curve, orient: Optional[bool] = True) -> Tuple[bool, float, float]: ...
	def FirstVertex(self, edge: TopoDS_Edge) -> TopoDS_Vertex: ...
	@overload
	def GetEndTangent2d(self, edge: TopoDS_Edge, face: TopoDS_Face, atEnd: bool, pos: gp_Pnt2d, tang: gp_Vec2d, dparam: Optional[float] = 0.0) -> bool: ...
	@overload
	def GetEndTangent2d(self, edge: TopoDS_Edge, surface: Geom_Surface, location: TopLoc_Location, atEnd: bool, pos: gp_Pnt2d, tang: gp_Vec2d, dparam: Optional[float] = 0.0) -> bool: ...
	def HasCurve3d(self, edge: TopoDS_Edge) -> bool: ...
	@overload
	def HasPCurve(self, edge: TopoDS_Edge, face: TopoDS_Face) -> bool: ...
	@overload
	def HasPCurve(self, edge: TopoDS_Edge, surface: Geom_Surface, location: TopLoc_Location) -> bool: ...
	def IsClosed3d(self, edge: TopoDS_Edge) -> bool: ...
	@overload
	def IsSeam(self, edge: TopoDS_Edge, face: TopoDS_Face) -> bool: ...
	@overload
	def IsSeam(self, edge: TopoDS_Edge, surface: Geom_Surface, location: TopLoc_Location) -> bool: ...
	def LastVertex(self, edge: TopoDS_Edge) -> TopoDS_Vertex: ...
	@overload
	def PCurve(self, edge: TopoDS_Edge, face: TopoDS_Face, C2d: Geom2d_Curve, orient: Optional[bool] = True) -> Tuple[bool, float, float]: ...
	@overload
	def PCurve(self, edge: TopoDS_Edge, surface: Geom_Surface, location: TopLoc_Location, C2d: Geom2d_Curve, orient: Optional[bool] = True) -> Tuple[bool, float, float]: ...
	def Status(self, status: ShapeExtend_Status) -> bool: ...

class ShapeAnalysis_FreeBoundData(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, freebound: TopoDS_Wire) -> None: ...
	def AddNotch(self, notch: TopoDS_Wire, width: float) -> None: ...
	def Area(self) -> float: ...
	def Clear(self) -> None: ...
	def FreeBound(self) -> TopoDS_Wire: ...
	def NbNotches(self) -> int: ...
	def Notch(self, index: int) -> TopoDS_Wire: ...
	@overload
	def NotchWidth(self, index: int) -> float: ...
	@overload
	def NotchWidth(self, notch: TopoDS_Wire) -> float: ...
	def Notches(self) -> TopTools_HSequenceOfShape: ...
	def Perimeter(self) -> float: ...
	def Ratio(self) -> float: ...
	def SetArea(self, area: float) -> None: ...
	def SetFreeBound(self, freebound: TopoDS_Wire) -> None: ...
	def SetPerimeter(self, perimeter: float) -> None: ...
	def SetRatio(self, ratio: float) -> None: ...
	def SetWidth(self, width: float) -> None: ...
	def Width(self) -> float: ...

class ShapeAnalysis_FreeBounds:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, shape: TopoDS_Shape, toler: float, splitclosed: Optional[bool] = False, splitopen: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, shape: TopoDS_Shape, splitclosed: Optional[bool] = False, splitopen: Optional[bool] = True, checkinternaledges: Optional[bool] = False) -> None: ...
	@staticmethod
	def ConnectEdgesToWires(edges: TopTools_HSequenceOfShape, toler: float, shared: bool, wires: TopTools_HSequenceOfShape) -> None: ...
	@overload
	@staticmethod
	def ConnectWiresToWires(iwires: TopTools_HSequenceOfShape, toler: float, shared: bool, owires: TopTools_HSequenceOfShape) -> None: ...
	@overload
	@staticmethod
	def ConnectWiresToWires(iwires: TopTools_HSequenceOfShape, toler: float, shared: bool, owires: TopTools_HSequenceOfShape, vertices: TopTools_DataMapOfShapeShape) -> None: ...
	@staticmethod
	def DispatchWires(wires: TopTools_HSequenceOfShape, closed: TopoDS_Compound, open: TopoDS_Compound) -> None: ...
	def GetClosedWires(self) -> TopoDS_Compound: ...
	def GetOpenWires(self) -> TopoDS_Compound: ...
	@staticmethod
	def SplitWires(wires: TopTools_HSequenceOfShape, toler: float, shared: bool, closed: TopTools_HSequenceOfShape, open: TopTools_HSequenceOfShape) -> None: ...

class ShapeAnalysis_FreeBoundsProperties:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, shape: TopoDS_Shape, tolerance: float, splitclosed: Optional[bool] = False, splitopen: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, shape: TopoDS_Shape, splitclosed: Optional[bool] = False, splitopen: Optional[bool] = False) -> None: ...
	def CheckContours(self, prec: Optional[float] = 0.0) -> bool: ...
	@overload
	def CheckNotches(self, prec: Optional[float] = 0.0) -> bool: ...
	@overload
	def CheckNotches(self, fbData: ShapeAnalysis_FreeBoundData, prec: Optional[float] = 0.0) -> bool: ...
	@overload
	def CheckNotches(self, freebound: TopoDS_Wire, num: int, notch: TopoDS_Wire, prec: Optional[float] = 0.0) -> Tuple[bool, float]: ...
	def ClosedFreeBound(self, index: int) -> ShapeAnalysis_FreeBoundData: ...
	def ClosedFreeBounds(self) -> ShapeAnalysis_HSequenceOfFreeBounds: ...
	def DispatchBounds(self) -> bool: ...
	def FillProperties(self, fbData: ShapeAnalysis_FreeBoundData, prec: Optional[float] = 0.0) -> bool: ...
	@overload
	def Init(self, shape: TopoDS_Shape, tolerance: float, splitclosed: Optional[bool] = False, splitopen: Optional[bool] = False) -> None: ...
	@overload
	def Init(self, shape: TopoDS_Shape, splitclosed: Optional[bool] = False, splitopen: Optional[bool] = False) -> None: ...
	def IsLoaded(self) -> bool: ...
	def NbClosedFreeBounds(self) -> int: ...
	def NbFreeBounds(self) -> int: ...
	def NbOpenFreeBounds(self) -> int: ...
	def OpenFreeBound(self, index: int) -> ShapeAnalysis_FreeBoundData: ...
	def OpenFreeBounds(self) -> ShapeAnalysis_HSequenceOfFreeBounds: ...
	def Perform(self) -> bool: ...
	def Shape(self) -> TopoDS_Shape: ...
	def Tolerance(self) -> float: ...

class ShapeAnalysis_Geom:
	@staticmethod
	def NearestPlane(Pnts: TColgp_Array1OfPnt, aPln: gp_Pln) -> Tuple[bool, float]: ...
	@staticmethod
	def PositionTrsf(coefs: TColStd_HArray2OfReal, trsf: gp_Trsf, unit: float, prec: float) -> bool: ...

class ShapeAnalysis_ShapeContents:
	def __init__(self) -> None: ...
	def BigSplineSec(self) -> TopTools_HSequenceOfShape: ...
	def Clear(self) -> None: ...
	def ClearFlags(self) -> None: ...
	def IndirectSec(self) -> TopTools_HSequenceOfShape: ...
	def GetModifyBigSplineMode(self) -> bool: ...
	def SetModifyBigSplineMode(self, value: bool) -> None: ...
	def GetModifyIndirectMode(self) -> bool: ...
	def SetModifyIndirectMode(self, value: bool) -> None: ...
	def GetModifyOffestSurfaceMode(self) -> bool: ...
	def SetModifyOffestSurfaceMode(self, value: bool) -> None: ...
	def GetModifyOffsetCurveMode(self) -> bool: ...
	def SetModifyOffsetCurveMode(self, value: bool) -> None: ...
	def GetModifyTrimmed2dMode(self) -> bool: ...
	def SetModifyTrimmed2dMode(self, value: bool) -> None: ...
	def GetModifyTrimmed3dMode(self) -> bool: ...
	def SetModifyTrimmed3dMode(self, value: bool) -> None: ...
	def NbBSplibeSurf(self) -> int: ...
	def NbBezierSurf(self) -> int: ...
	def NbBigSplines(self) -> int: ...
	def NbC0Curves(self) -> int: ...
	def NbC0Surfaces(self) -> int: ...
	def NbEdges(self) -> int: ...
	def NbFaceWithSevWires(self) -> int: ...
	def NbFaces(self) -> int: ...
	def NbFreeEdges(self) -> int: ...
	def NbFreeFaces(self) -> int: ...
	def NbFreeWires(self) -> int: ...
	def NbIndirectSurf(self) -> int: ...
	def NbNoPCurve(self) -> int: ...
	def NbOffsetCurves(self) -> int: ...
	def NbOffsetSurf(self) -> int: ...
	def NbSharedEdges(self) -> int: ...
	def NbSharedFaces(self) -> int: ...
	def NbSharedFreeEdges(self) -> int: ...
	def NbSharedFreeWires(self) -> int: ...
	def NbSharedShells(self) -> int: ...
	def NbSharedSolids(self) -> int: ...
	def NbSharedVertices(self) -> int: ...
	def NbSharedWires(self) -> int: ...
	def NbShells(self) -> int: ...
	def NbSolids(self) -> int: ...
	def NbSolidsWithVoids(self) -> int: ...
	def NbTrimSurf(self) -> int: ...
	def NbTrimmedCurve2d(self) -> int: ...
	def NbTrimmedCurve3d(self) -> int: ...
	def NbVertices(self) -> int: ...
	def NbWireWithSevSeams(self) -> int: ...
	def NbWireWitnSeam(self) -> int: ...
	def NbWires(self) -> int: ...
	def OffsetCurveSec(self) -> TopTools_HSequenceOfShape: ...
	def OffsetSurfaceSec(self) -> TopTools_HSequenceOfShape: ...
	def Perform(self, shape: TopoDS_Shape) -> None: ...
	def Trimmed2dSec(self) -> TopTools_HSequenceOfShape: ...
	def Trimmed3dSec(self) -> TopTools_HSequenceOfShape: ...

class ShapeAnalysis_ShapeTolerance:
	def __init__(self) -> None: ...
	def AddTolerance(self, shape: TopoDS_Shape, type: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> None: ...
	def GlobalTolerance(self, mode: int) -> float: ...
	def InTolerance(self, shape: TopoDS_Shape, valmin: float, valmax: float, type: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> TopTools_HSequenceOfShape: ...
	def InitTolerance(self) -> None: ...
	def OverTolerance(self, shape: TopoDS_Shape, value: float, type: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> TopTools_HSequenceOfShape: ...
	def Tolerance(self, shape: TopoDS_Shape, mode: int, type: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> float: ...

class ShapeAnalysis_Shell:
	def __init__(self) -> None: ...
	def BadEdges(self) -> TopoDS_Compound: ...
	def CheckOrientedShells(self, shape: TopoDS_Shape, alsofree: Optional[bool] = False, checkinternaledges: Optional[bool] = False) -> bool: ...
	def Clear(self) -> None: ...
	def FreeEdges(self) -> TopoDS_Compound: ...
	def HasBadEdges(self) -> bool: ...
	def HasConnectedEdges(self) -> bool: ...
	def HasFreeEdges(self) -> bool: ...
	def IsLoaded(self, shape: TopoDS_Shape) -> bool: ...
	def LoadShells(self, shape: TopoDS_Shape) -> None: ...
	def Loaded(self, num: int) -> TopoDS_Shape: ...
	def NbLoaded(self) -> int: ...

class ShapeAnalysis_Surface(Standard_Transient):
	def __init__(self, S: Geom_Surface) -> None: ...
	def Adaptor3d(self) -> GeomAdaptor_HSurface: ...
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def ComputeBoundIsos(self) -> None: ...
	def DegeneratedValues(self, P3d: gp_Pnt, preci: float, firstP2d: gp_Pnt2d, lastP2d: gp_Pnt2d, forward: Optional[bool] = True) -> Tuple[bool, float, float]: ...
	def Gap(self) -> float: ...
	def GetBoxUF(self) -> Bnd_Box: ...
	def GetBoxUL(self) -> Bnd_Box: ...
	def GetBoxVF(self) -> Bnd_Box: ...
	def GetBoxVL(self) -> Bnd_Box: ...
	def HasSingularities(self, preci: float) -> bool: ...
	@overload
	def Init(self, S: Geom_Surface) -> None: ...
	@overload
	def Init(self, other: ShapeAnalysis_Surface) -> None: ...
	@overload
	def IsDegenerated(self, P3d: gp_Pnt, preci: float) -> bool: ...
	@overload
	def IsDegenerated(self, p2d1: gp_Pnt2d, p2d2: gp_Pnt2d, tol: float, ratio: float) -> bool: ...
	def IsUClosed(self, preci: Optional[float] = -1) -> bool: ...
	def IsVClosed(self, preci: Optional[float] = -1) -> bool: ...
	def NbSingularities(self, preci: float) -> int: ...
	def NextValueOfUV(self, p2dPrev: gp_Pnt2d, P3D: gp_Pnt, preci: float, maxpreci: Optional[float] = -1.0) -> gp_Pnt2d: ...
	@overload
	def ProjectDegenerated(self, P3d: gp_Pnt, preci: float, neighbour: gp_Pnt2d, result: gp_Pnt2d) -> bool: ...
	@overload
	def ProjectDegenerated(self, nbrPnt: int, points: TColgp_SequenceOfPnt, pnt2d: TColgp_SequenceOfPnt2d, preci: float, direct: bool) -> bool: ...
	def SetDomain(self, U1: float, U2: float, V1: float, V2: float) -> None: ...
	def Singularity(self, num: int, P3d: gp_Pnt, firstP2d: gp_Pnt2d, lastP2d: gp_Pnt2d) -> Tuple[bool, float, float, float, bool]: ...
	def Surface(self) -> Geom_Surface: ...
	def TrueAdaptor3d(self) -> GeomAdaptor_HSurface: ...
	def UCloseVal(self) -> float: ...
	def UIso(self, U: float) -> Geom_Curve: ...
	def UVFromIso(self, P3D: gp_Pnt, preci: float) -> Tuple[float, float, float]: ...
	def VCloseVal(self) -> float: ...
	def VIso(self, V: float) -> Geom_Curve: ...
	@overload
	def Value(self, u: float, v: float) -> gp_Pnt: ...
	@overload
	def Value(self, p2d: gp_Pnt2d) -> gp_Pnt: ...
	def ValueOfUV(self, P3D: gp_Pnt, preci: float) -> gp_Pnt2d: ...

class ShapeAnalysis_TransferParameters(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, E: TopoDS_Edge, F: TopoDS_Face) -> None: ...
	def Init(self, E: TopoDS_Edge, F: TopoDS_Face) -> None: ...
	def IsSameRange(self) -> bool: ...
	@overload
	def Perform(self, Params: TColStd_HSequenceOfReal, To2d: bool) -> TColStd_HSequenceOfReal: ...
	@overload
	def Perform(self, Param: float, To2d: bool) -> float: ...
	def SetMaxTolerance(self, maxtol: float) -> None: ...
	def TransferRange(self, newEdge: TopoDS_Edge, prevPar: float, currPar: float, To2d: bool) -> None: ...

class ShapeAnalysis_Wire(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, wire: TopoDS_Wire, face: TopoDS_Face, precision: float) -> None: ...
	@overload
	def __init__(self, sbwd: ShapeExtend_WireData, face: TopoDS_Face, precision: float) -> None: ...
	def CheckClosed(self, prec: Optional[float] = 0.0) -> bool: ...
	@overload
	def CheckConnected(self, prec: Optional[float] = 0.0) -> bool: ...
	@overload
	def CheckConnected(self, num: int, prec: Optional[float] = 0.0) -> bool: ...
	def CheckCurveGap(self, num: Optional[int] = 0) -> bool: ...
	def CheckCurveGaps(self) -> bool: ...
	@overload
	def CheckDegenerated(self) -> bool: ...
	@overload
	def CheckDegenerated(self, num: int, dgnr1: gp_Pnt2d, dgnr2: gp_Pnt2d) -> bool: ...
	@overload
	def CheckDegenerated(self, num: int) -> bool: ...
	def CheckEdgeCurves(self) -> bool: ...
	def CheckGap2d(self, num: Optional[int] = 0) -> bool: ...
	def CheckGap3d(self, num: Optional[int] = 0) -> bool: ...
	def CheckGaps2d(self) -> bool: ...
	def CheckGaps3d(self) -> bool: ...
	@overload
	def CheckIntersectingEdges(self, num: int, points2d: IntRes2d_SequenceOfIntersectionPoint, points3d: TColgp_SequenceOfPnt, errors: TColStd_SequenceOfReal) -> bool: ...
	@overload
	def CheckIntersectingEdges(self, num: int) -> bool: ...
	@overload
	def CheckIntersectingEdges(self, num1: int, num2: int, points2d: IntRes2d_SequenceOfIntersectionPoint, points3d: TColgp_SequenceOfPnt, errors: TColStd_SequenceOfReal) -> bool: ...
	@overload
	def CheckIntersectingEdges(self, num1: int, num2: int) -> bool: ...
	@overload
	def CheckLacking(self) -> bool: ...
	@overload
	def CheckLacking(self, num: int, Tolerance: float, p2d1: gp_Pnt2d, p2d2: gp_Pnt2d) -> bool: ...
	@overload
	def CheckLacking(self, num: int, Tolerance: Optional[float] = 0.0) -> bool: ...
	def CheckLoop(self, aMapLoopVertices: TopTools_IndexedMapOfShape, aMapVertexEdges: TopTools_DataMapOfShapeListOfShape, aMapSmallEdges: TopTools_MapOfShape, aMapSeemEdges: TopTools_MapOfShape) -> bool: ...
	def CheckNotchedEdges(self, num: int, Tolerance: Optional[float] = 0.0) -> Tuple[bool, int, float]: ...
	@overload
	def CheckOrder(self, isClosed: Optional[bool] = True, mode3d: Optional[bool] = True) -> bool: ...
	@overload
	def CheckOrder(self, sawo: ShapeAnalysis_WireOrder, isClosed: Optional[bool] = True, mode3d: Optional[bool] = True) -> bool: ...
	def CheckOuterBound(self, APIMake: Optional[bool] = True) -> bool: ...
	@overload
	def CheckSeam(self, num: int, C1: Geom2d_Curve, C2: Geom2d_Curve) -> Tuple[bool, float, float]: ...
	@overload
	def CheckSeam(self, num: int) -> bool: ...
	@overload
	def CheckSelfIntersectingEdge(self, num: int, points2d: IntRes2d_SequenceOfIntersectionPoint, points3d: TColgp_SequenceOfPnt) -> bool: ...
	@overload
	def CheckSelfIntersectingEdge(self, num: int) -> bool: ...
	def CheckSelfIntersection(self) -> bool: ...
	@overload
	def CheckShapeConnect(self, shape: TopoDS_Shape, prec: Optional[float] = 0.0) -> bool: ...
	@overload
	def CheckShapeConnect(self, shape: TopoDS_Shape, prec: Optional[float] = 0.0) -> Tuple[bool, float, float, float, float]: ...
	@overload
	def CheckSmall(self, precsmall: Optional[float] = 0.0) -> bool: ...
	@overload
	def CheckSmall(self, num: int, precsmall: Optional[float] = 0.0) -> bool: ...
	def CheckSmallArea(self, theWire: TopoDS_Wire) -> bool: ...
	def CheckTail(self, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge, theMaxSine: float, theMaxWidth: float, theMaxTolerance: float, theEdge11: TopoDS_Edge, theEdge12: TopoDS_Edge, theEdge21: TopoDS_Edge, theEdge22: TopoDS_Edge) -> bool: ...
	def ClearStatuses(self) -> None: ...
	def Face(self) -> TopoDS_Face: ...
	@overload
	def Init(self, wire: TopoDS_Wire, face: TopoDS_Face, precision: float) -> None: ...
	@overload
	def Init(self, sbwd: ShapeExtend_WireData, face: TopoDS_Face, precision: float) -> None: ...
	def IsLoaded(self) -> bool: ...
	def IsReady(self) -> bool: ...
	def LastCheckStatus(self, Status: ShapeExtend_Status) -> bool: ...
	@overload
	def Load(self, wire: TopoDS_Wire) -> None: ...
	@overload
	def Load(self, sbwd: ShapeExtend_WireData) -> None: ...
	def MaxDistance2d(self) -> float: ...
	def MaxDistance3d(self) -> float: ...
	def MinDistance2d(self) -> float: ...
	def MinDistance3d(self) -> float: ...
	def NbEdges(self) -> int: ...
	def Perform(self) -> bool: ...
	def Precision(self) -> float: ...
	def SetFace(self, face: TopoDS_Face) -> None: ...
	def SetPrecision(self, precision: float) -> None: ...
	@overload
	def SetSurface(self, surface: Geom_Surface) -> None: ...
	@overload
	def SetSurface(self, surface: Geom_Surface, location: TopLoc_Location) -> None: ...
	def StatusClosed(self, Status: ShapeExtend_Status) -> bool: ...
	def StatusConnected(self, Status: ShapeExtend_Status) -> bool: ...
	def StatusCurveGaps(self, Status: ShapeExtend_Status) -> bool: ...
	def StatusDegenerated(self, Status: ShapeExtend_Status) -> bool: ...
	def StatusEdgeCurves(self, Status: ShapeExtend_Status) -> bool: ...
	def StatusGaps2d(self, Status: ShapeExtend_Status) -> bool: ...
	def StatusGaps3d(self, Status: ShapeExtend_Status) -> bool: ...
	def StatusLacking(self, Status: ShapeExtend_Status) -> bool: ...
	def StatusLoop(self, Status: ShapeExtend_Status) -> bool: ...
	def StatusOrder(self, Status: ShapeExtend_Status) -> bool: ...
	def StatusSelfIntersection(self, Status: ShapeExtend_Status) -> bool: ...
	def StatusSmall(self, Status: ShapeExtend_Status) -> bool: ...
	def Surface(self) -> ShapeAnalysis_Surface: ...
	def WireData(self) -> ShapeExtend_WireData: ...

class ShapeAnalysis_WireOrder:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, mode3d: bool, tol: float) -> None: ...
	@overload
	def Add(self, start3d: gp_XYZ, end3d: gp_XYZ) -> None: ...
	@overload
	def Add(self, start2d: gp_XY, end2d: gp_XY) -> None: ...
	def Chain(self, num: int) -> Tuple[int, int]: ...
	def Clear(self) -> None: ...
	def Couple(self, num: int) -> Tuple[int, int]: ...
	def Gap(self, num: Optional[int] = 0) -> float: ...
	def IsDone(self) -> bool: ...
	def GetKeepLoopsMode(self) -> bool: ...
	def SetKeepLoopsMode(self, value: bool) -> None: ...
	def NbChains(self) -> int: ...
	def NbCouples(self) -> int: ...
	def NbEdges(self) -> int: ...
	def Ordered(self, n: int) -> int: ...
	def Perform(self, closed: Optional[bool] = True) -> None: ...
	def SetChains(self, gap: float) -> None: ...
	def SetCouples(self, gap: float) -> None: ...
	def SetMode(self, mode3d: bool, tol: float) -> None: ...
	def Status(self) -> int: ...
	def Tolerance(self) -> float: ...
	def XY(self, num: int, start2d: gp_XY, end2d: gp_XY) -> None: ...
	def XYZ(self, num: int, start3d: gp_XYZ, end3d: gp_XYZ) -> None: ...

class ShapeAnalysis_WireVertex:
	def __init__(self) -> None: ...
	def Analyze(self) -> None: ...
	def Data(self, num: int, pos: gp_XYZ) -> Tuple[int, float, float]: ...
	@overload
	def Init(self, wire: TopoDS_Wire, preci: float) -> None: ...
	@overload
	def Init(self, swbd: ShapeExtend_WireData, preci: float) -> None: ...
	def IsDone(self) -> bool: ...
	@overload
	def Load(self, wire: TopoDS_Wire) -> None: ...
	@overload
	def Load(self, sbwd: ShapeExtend_WireData) -> None: ...
	def NbEdges(self) -> int: ...
	def NextCriter(self, crit: int, num: Optional[int] = 0) -> int: ...
	def NextStatus(self, stat: int, num: Optional[int] = 0) -> int: ...
	def Position(self, num: int) -> gp_XYZ: ...
	def Precision(self) -> float: ...
	def SetClose(self, num: int) -> None: ...
	def SetDisjoined(self, num: int) -> None: ...
	def SetEnd(self, num: int, pos: gp_XYZ, ufol: float) -> None: ...
	def SetInters(self, num: int, pos: gp_XYZ, upre: float, ufol: float) -> None: ...
	def SetPrecision(self, preci: float) -> None: ...
	def SetSameCoords(self, num: int) -> None: ...
	def SetSameVertex(self, num: int) -> None: ...
	def SetStart(self, num: int, pos: gp_XYZ, upre: float) -> None: ...
	def Status(self, num: int) -> int: ...
	def UFollowing(self, num: int) -> float: ...
	def UPrevious(self, num: int) -> float: ...
	def WireData(self) -> ShapeExtend_WireData: ...

class ShapeAnalysis_TransferParametersProj(ShapeAnalysis_TransferParameters):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, E: TopoDS_Edge, F: TopoDS_Face) -> None: ...
	@overload
	@staticmethod
	def CopyNMVertex(theVert: TopoDS_Vertex, toedge: TopoDS_Edge, fromedge: TopoDS_Edge) -> TopoDS_Vertex: ...
	@overload
	@staticmethod
	def CopyNMVertex(theVert: TopoDS_Vertex, toFace: TopoDS_Face, fromFace: TopoDS_Face) -> TopoDS_Vertex: ...
	def GetForceProjection(self) -> bool: ...
	def SetForceProjection(self, value: bool) -> None: ...
	def Init(self, E: TopoDS_Edge, F: TopoDS_Face) -> None: ...
	def IsSameRange(self) -> bool: ...
	@overload
	def Perform(self, Papams: TColStd_HSequenceOfReal, To2d: bool) -> TColStd_HSequenceOfReal: ...
	@overload
	def Perform(self, Param: float, To2d: bool) -> float: ...
	def TransferRange(self, newEdge: TopoDS_Edge, prevPar: float, currPar: float, Is2d: bool) -> None: ...

#classnotwrapped
class ShapeAnalysis_BoxBndTreeSelector: ...

#classnotwrapped
class ShapeCustom_ConvertToRevolution: ...

# harray1 classes
# harray2 classes
# hsequence classes

class ShapeAnalysis_HSequenceOfFreeBounds(ShapeAnalysis_SequenceOfFreeBounds, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: ShapeAnalysis_SequenceOfFreeBounds) -> None: ...
    def Sequence(self) -> ShapeAnalysis_SequenceOfFreeBounds: ...
    def Append(self, theSequence: ShapeAnalysis_SequenceOfFreeBounds) -> None: ...


shapeanalysis_AdjustByPeriod = shapeanalysis.AdjustByPeriod
shapeanalysis_AdjustToPeriod = shapeanalysis.AdjustToPeriod
shapeanalysis_ContourArea = shapeanalysis.ContourArea
shapeanalysis_FindBounds = shapeanalysis.FindBounds
shapeanalysis_GetFaceUVBounds = shapeanalysis.GetFaceUVBounds
shapeanalysis_IsOuterBound = shapeanalysis.IsOuterBound
shapeanalysis_OuterWire = shapeanalysis.OuterWire
shapeanalysis_TotCross2D = shapeanalysis.TotCross2D
ShapeAnalysis_Curve_GetSamplePoints = ShapeAnalysis_Curve.GetSamplePoints
ShapeAnalysis_Curve_GetSamplePoints = ShapeAnalysis_Curve.GetSamplePoints
ShapeAnalysis_Curve_IsClosed = ShapeAnalysis_Curve.IsClosed
ShapeAnalysis_Curve_IsPeriodic = ShapeAnalysis_Curve.IsPeriodic
ShapeAnalysis_Curve_IsPeriodic = ShapeAnalysis_Curve.IsPeriodic
ShapeAnalysis_Curve_IsPlanar = ShapeAnalysis_Curve.IsPlanar
ShapeAnalysis_Curve_IsPlanar = ShapeAnalysis_Curve.IsPlanar
ShapeAnalysis_Edge_ComputeDeviation = ShapeAnalysis_Edge.ComputeDeviation
ShapeAnalysis_FreeBounds_ConnectEdgesToWires = ShapeAnalysis_FreeBounds.ConnectEdgesToWires
ShapeAnalysis_FreeBounds_ConnectWiresToWires = ShapeAnalysis_FreeBounds.ConnectWiresToWires
ShapeAnalysis_FreeBounds_ConnectWiresToWires = ShapeAnalysis_FreeBounds.ConnectWiresToWires
ShapeAnalysis_FreeBounds_DispatchWires = ShapeAnalysis_FreeBounds.DispatchWires
ShapeAnalysis_FreeBounds_SplitWires = ShapeAnalysis_FreeBounds.SplitWires
ShapeAnalysis_Geom_NearestPlane = ShapeAnalysis_Geom.NearestPlane
ShapeAnalysis_Geom_PositionTrsf = ShapeAnalysis_Geom.PositionTrsf
ShapeAnalysis_TransferParametersProj_CopyNMVertex = ShapeAnalysis_TransferParametersProj.CopyNMVertex
ShapeAnalysis_TransferParametersProj_CopyNMVertex = ShapeAnalysis_TransferParametersProj.CopyNMVertex



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XCAFNoteObjects module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xcafnoteobjects.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XCAFNoteObjects
else:
    import _XCAFNoteObjects

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XCAFNoteObjects.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XCAFNoteObjects.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XCAFNoteObjects.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XCAFNoteObjects.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XCAFNoteObjects.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XCAFNoteObjects.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XCAFNoteObjects.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XCAFNoteObjects.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XCAFNoteObjects.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XCAFNoteObjects.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XCAFNoteObjects.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XCAFNoteObjects.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XCAFNoteObjects.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XCAFNoteObjects.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XCAFNoteObjects.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XCAFNoteObjects.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XCAFNoteObjects.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XCAFNoteObjects:
_XCAFNoteObjects.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XCAFNoteObjects.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TopAbs
import OCC.Core.TopLoc

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XCAFNoteObjects_NoteObject_Create() -> "opencascade::handle< XCAFNoteObjects_NoteObject >":
    return _XCAFNoteObjects.Handle_XCAFNoteObjects_NoteObject_Create()

def Handle_XCAFNoteObjects_NoteObject_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XCAFNoteObjects_NoteObject >":
    return _XCAFNoteObjects.Handle_XCAFNoteObjects_NoteObject_DownCast(t)

def Handle_XCAFNoteObjects_NoteObject_IsNull(t: "opencascade::handle< XCAFNoteObjects_NoteObject > const &") -> "bool":
    return _XCAFNoteObjects.Handle_XCAFNoteObjects_NoteObject_IsNull(t)
class XCAFNoteObjects_NoteObject(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty object.

        Returns
        -------
        None
        Copy constructor.

        Parameters
        ----------
        theObj: XCAFNoteObjects_NoteObject

        Returns
        -------
        None

        """
        _XCAFNoteObjects.XCAFNoteObjects_NoteObject_swiginit(self, _XCAFNoteObjects.new_XCAFNoteObjects_NoteObject(*args))

    def GetPlane(self, *args) -> "gp_Ax2 const":
        r"""
        Returns a right-handed coordinate system of the plane.

        Returns
        -------
        gp_Ax2

        """
        return _XCAFNoteObjects.XCAFNoteObjects_NoteObject_GetPlane(self, *args)

    def GetPoint(self, *args) -> "gp_Pnt const":
        r"""
        Returns the attachment point on the annotated object.

        Returns
        -------
        gp_Pnt

        """
        return _XCAFNoteObjects.XCAFNoteObjects_NoteObject_GetPoint(self, *args)

    def GetPointText(self, *args) -> "gp_Pnt const":
        r"""
        Returns the text position.

        Returns
        -------
        gp_Pnt

        """
        return _XCAFNoteObjects.XCAFNoteObjects_NoteObject_GetPointText(self, *args)

    def GetPresentation(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns a tesselated annotation if specified.

        Returns
        -------
        TopoDS_Shape

        """
        return _XCAFNoteObjects.XCAFNoteObjects_NoteObject_GetPresentation(self, *args)

    def HasPlane(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if plane is specified.

        Returns
        -------
        bool

        """
        return _XCAFNoteObjects.XCAFNoteObjects_NoteObject_HasPlane(self, *args)

    def HasPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the attachment point on the annotated object is specified.

        Returns
        -------
        bool

        """
        return _XCAFNoteObjects.XCAFNoteObjects_NoteObject_HasPoint(self, *args)

    def HasPointText(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the text position is specified.

        Returns
        -------
        bool

        """
        return _XCAFNoteObjects.XCAFNoteObjects_NoteObject_HasPointText(self, *args)

    def Reset(self, *args) -> "void":
        r"""
        Resets data to the state after calling the default constructor.

        Returns
        -------
        None

        """
        return _XCAFNoteObjects.XCAFNoteObjects_NoteObject_Reset(self, *args)

    def SetPlane(self, *args) -> "void":
        r"""
        Sets a right-handed coordinate system of the plane.

        Parameters
        ----------
        thePlane: gp_Ax2

        Returns
        -------
        None

        """
        return _XCAFNoteObjects.XCAFNoteObjects_NoteObject_SetPlane(self, *args)

    def SetPoint(self, *args) -> "void":
        r"""
        Sets the anchor point on the annotated object.

        Parameters
        ----------
        thePnt: gp_Pnt

        Returns
        -------
        None

        """
        return _XCAFNoteObjects.XCAFNoteObjects_NoteObject_SetPoint(self, *args)

    def SetPointText(self, *args) -> "void":
        r"""
        Sets the text position.

        Parameters
        ----------
        thePnt: gp_Pnt

        Returns
        -------
        None

        """
        return _XCAFNoteObjects.XCAFNoteObjects_NoteObject_SetPointText(self, *args)

    def SetPresentation(self, *args) -> "void":
        r"""
        Sets a tesselated annotation.

        Parameters
        ----------
        thePresentation: TopoDS_Shape

        Returns
        -------
        None

        """
        return _XCAFNoteObjects.XCAFNoteObjects_NoteObject_SetPresentation(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XCAFNoteObjects_NoteObject_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XCAFNoteObjects.delete_XCAFNoteObjects_NoteObject

# Register XCAFNoteObjects_NoteObject in _XCAFNoteObjects:
_XCAFNoteObjects.XCAFNoteObjects_NoteObject_swigregister(XCAFNoteObjects_NoteObject)





